@@ -33,9 +33,12 @@ def _find_aspera_keypath(ascp_key=None):
             aspera_dir, "connect", "etc", "asperaweb_id_dsa.openssh"
         )
     else:
-        aspera_keypath = ascp_key
+        aspera_keypath = ascp_key.strip('"')
     if os.path.isfile(aspera_keypath):
         return aspera_keypath
+    else:
+        print(aspera_keypath)
+        raise("Error in asperaweb_id_dsa.openssh file")
 
 
 def verify_sra_download(log, SRR):
